import {
  addCurrencies,
  agencyRates,
  getAllCurrencies,
  updateCurrencies,
} from "../services/admin.service.js";

export const getUsers = async (req, res, next) => {
  try {
    const users = await User.find();
    res.json(users);
  } catch (err) {
    next(err);
  }
};

export const createUser = async (req, res, next) => {
  const { name, email, age } = req.body;

  try {
    const user = new User({ name, email, age });
    const savedUser = await user.save();
    res.status(201).json(savedUser);
  } catch (err) {
    next(err);
  }
};

export const getAgencyRates = async (req, res, next) => {
  try {
    const users = await agencyRates(
      req.body.authorizationToken,
      req.body.username
    );
    res.json(users);
  } catch (err) {
    next(err);
  }
};

export const getCurrencies = async (req, res, next) => {
  try {
    const users = await getAllCurrencies(
      req.params.authorizationToken,
      req.params.username,
      req.query.currencyId
    );
    res.json(users);
  } catch (err) {
    next(err);
  }
};

export const addCurrency = async (req, res, next) => {
  try {
    const users = await addCurrencies(
      req.params.authorizationToken,
      req.params.username,
      req.body
    );
    res.json(users);
  } catch (err) {
    next(err);
  }
};

export const updateCurrency = async (req, res, next) => {
  try {
    const users = await updateCurrencies(
      req.params.authorizationToken,
      req.params.username,
      req.body
    );
    res.json(users);
  } catch (err) {
    next(err);
  }
};
