import { APIError } from "rest-api-errors";

export const errorHandler = (err, req, res, next) => {
  const error =
    err.status === 401 || err instanceof APIError
      ? err
      : new InternalServerError();

  if (process.env.NODE_ENV !== "production") {
    console.log(err);
  }

  if (err.name === "AxiosError") {
    return res
      .status(err.response.status || 422)
      .json({ success: false, message: err.response.statusText });
  }

  if (err.name === "ValidationError") {
    return res
      .status(err.code || 422)
      .json({ success: false, message: err.message });
  }

  if (err.name === "CastError" && err.path === "_id") {
    return res
      .status(422)
      .json({ success: false, message: "Invalid ObjectID." });
  }

  if (err.code === "ERR_BAD_REQUEST") {
    return res.status(err?.response?.status || 422).json({
      success: false,
      message: err?.response?.data?.error?.message,
    });
  }

  return res.status(err.status || 500).json({
    success: false,
    message: err.message,
  });
};
