import axios from "axios";
import { APIError } from "rest-api-errors";

export const fetchCountryPermission = async (authorizationToken, username) => {
  try {
    // Ensure you have the right URL and that your server is reachable
    console.log(
      "URL being requested:",
      `${process.env.SWAGGER_URL}/master/country/country-permission/add/country-permission-dropdown`
    );

    const response = await axios.get(
      `${process.env.SWAGGER_URL}/master/country/country-permission/add/country-permission-dropdown`,
      {
        headers: {
          Authorization: authorizationToken,
          Accept: "application/json",
          username: username,
        },
      }
    );

    // Log the response for debugging
    console.log("Response data:", response.data);

    return response.data;
  } catch (error) {
    console.error("Error occurred:", error.response || error.message || error);
    throw new APIError(
      error?.response?.status,
      error?.response?.status?.toString(),
      error?.response?.statusText
    );
  }
};

export const fetchBaseCountry = async (authorizationToken, username) => {
  try {
    // Ensure you have the right URL and that your server is reachable
    console.log(
      "URL being requested:",
      `${process.env.SWAGGER_URL}/master/country/country-permission/base-country-dropdown`
    );

    const response = await axios.get(
      `${process.env.SWAGGER_URL}/master/country/country-permission/base-country-dropdown`,
      {
        headers: {
          Authorization: authorizationToken,
          Accept: "application/json",
          username: username,
        },
      }
    );

    // Log the response for debugging
    console.log("Response data:", response.data);

    return response.data;
  } catch (error) {
    console.error("Error occurred:", error.response || error.message || error);
    throw new APIError(
      error?.response?.status,
      error?.response?.status?.toString(),
      error?.response?.statusText
    );
  }
};

export const fetchTargetCountryByCountryId = async (
  authorizationToken,
  username,
  countryId
) => {
  try {
    // Ensure you have the right URL and that your server is reachable
    console.log(
      "URL being requested:",
      `${process.env.SWAGGER_URL}master/country/country-permission/target-country-dropdown?countryId=${countryId}`
    );

    const response = await axios.get(
      `${process.env.SWAGGER_URL}master/country/country-permission/target-country-dropdown?countryId=${countryId}`,
      {
        headers: {
          Authorization: authorizationToken,
          Accept: "application/json",
          username: username,
        },
      }
    );

    // Log the response for debugging
    console.log("Response data:", response.data);

    return response.data;
  } catch (error) {
    console.error("Error occurred:", error.response || error.message || error);
    throw new APIError(
      error?.response?.status,
      error?.response?.status?.toString(),
      error?.response?.statusText
    );
  }
};

// Add more functions here as needed for the remaining endpoints

// Note: Make sure to replace `${process.env.SWAGGER_URL}` with your actual environment variable if different.
