import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';

import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { LoginComponent } from './login/login.component';
import { DashboardLayoutComponent } from './dashboard-layout/dashboard-layout.component';
import { CountryManagementComponent } from './country-management/country-management.component';
import { GlobalComponent } from './global/global.component';
import { ManageCurrencyComponent } from './manage-currency/manage-currency.component';
import { ManageExchangeRateComponent } from './manage-exchange-rate/manage-exchange-rate.component';
import { ManageAgentCommissionComponent } from './manage-agent-commission/manage-agent-commission.component';
import { UserManagementComponent } from './user-management/user-management.component';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';
import { AgencyRatesComponent } from './agency-rates/agency-rates.component';
import { AgentComponent } from './agent/agent.component';
import { AgentBranchComponent } from './agent-branch/agent-branch.component';
import { AgentWiseCommissionComponent } from './agent-wise-commission/agent-wise-commission.component';

// modules
import { ModalModule } from 'ngx-bootstrap/modal';
import { NgSelectModule } from '@ng-select/ng-select';
import { ManageCountryPermissionComponent } from './manage-country-permission/manage-country-permission.component';
import { TokenInterceptor } from './services/token.interceptor';
import { ManagePurposeOfTransferComponent } from './manage-purpose-of-transfer/manage-purpose-of-transfer.component';
import { ManageModeOfPaymentComponent } from './manage-mode-of-payment/manage-mode-of-payment.component';
import { ManageCityComponent } from './manage-city/manage-city.component';
import { ManageLocationComponent } from './manage-location/manage-location.component';
import { BankRatesComponent } from './bank-rates/bank-rates.component';
import { MarginsSpecificSendingCountryComponent } from './margins-specific-sending-country/margins-specific-sending-country.component';
import { AgentWiseRatesComponent } from './agent-wise-rates/agent-wise-rates.component';
import { MarginsSpecificSendingReceivingCountryComponent } from './margins-specific-sending-receiving-country/margins-specific-sending-receiving-country.component';
import { DailyRatesComponent } from './daily-rates/daily-rates.component';
import { CountryWiseCommissionComponent } from './country-wise-commission/country-wise-commission.component';
import { CifWiseMarginsComponent } from './cif-wise-margins/cif-wise-margins.component';
import { RatesMinMaxComponent } from './rates-min-max/rates-min-max.component';
import { EditTransactionComponent } from './edit-transaction/edit-transaction.component';
import { EditTransactionDetailComponent } from './edit-transaction-detail/edit-transaction-detail.component';
import { ViewTransactionStatusComponent } from './view-transaction-status/view-transaction-status.component';
import { StopPaymentComponent } from './stop-payment/stop-payment.component';
import { ManageAgentBranchesComponent } from './manage-agent-branches/manage-agent-branches.component';
import { AllSentTransactionsComponent } from './all-sent-transactions/all-sent-transactions.component';
import { CancellationRequestComponent } from './cancellation-request/cancellation-request.component';
import { ViewCancelTransactionComponent } from './view-cancel-transaction/view-cancel-transaction.component';
import { ViewReceiveTransactionComponent } from './view-receive-transaction/view-receive-transaction.component';
import { ViewComplianceListComponent } from './view-compliance-list/view-compliance-list.component';
import { SuspiciousTransactionReportComponent } from './suspicious-transaction-report/suspicious-transaction-report.component';
import { IndianInboundTransactionReportComponent } from './indian-inbound-transaction-report/indian-inbound-transaction-report.component';
import { HighValueTransactionReportComponent } from './high-value-transaction-report/high-value-transaction-report.component';
import { ComplianceReleasedTransactionReportComponent } from './compliance-released-transaction-report/compliance-released-transaction-report.component';
import { ComplianceHoldTransactionReportComponent } from './compliance-hold-transaction-report/compliance-hold-transaction-report.component';
import { TransactionAccountingDetailsComponent } from './transaction-accounting-details/transaction-accounting-details.component';
import { SearchTransactionsComponent } from './search-transactions/search-transactions.component';
import { CancelPaidTransactionComponent } from './cancel-paid-transaction/cancel-paid-transaction.component';
import { SearchTransactionModeWiseComponent } from './search-transaction-mode-wise/search-transaction-mode-wise.component';
import { CtaHoldSummaryComponent } from './cta-hold-summary/cta-hold-summary.component';
import { ReceiveTransactionStatusSummaryComponent } from './receive-transaction-status-summary/receive-transaction-status-summary.component';
import { SentTransactionSummaryComponent } from './sent-transaction-summary/sent-transaction-summary.component';
import { ViewDuplicateTransactionsComponent } from './view-duplicate-transactions/view-duplicate-transactions.component';
import { CustomerRegistrationComponent } from './customer-registration/customer-registration.component';
import { EditCustomerRegistrationComponent } from './edit-customer-registration/edit-customer-registration.component';
import { BeneficiaryActivationComponent } from './beneficiary-activation/beneficiary-activation.component';
import { DownloadTransactionsFileComponent } from './download-transactions-file/download-transactions-file.component';
import { UploadTransactionsFileComponent } from './upload-transactions-file/upload-transactions-file.component';
import { VostroAccountBalanceComponent } from './vostro-account-balance/vostro-account-balance.component';
import { GlobalTransactionLimitComponent } from './global-transaction-limit/global-transaction-limit.component';
import { CtaHoldMarginComponent } from './cta-hold-margin/cta-hold-margin.component';
import { ManagePremiumMarginsComponent } from './manage-premium-margins/manage-premium-margins.component';
import { EditModeOfPaymentComponent } from './edit-mode-of-payment/edit-mode-of-payment.component';
import { SendingAgentWiseComponent } from './sending-agent-wise/sending-agent-wise.component';
import { SendingAgentMarginComponent } from './sending-agent-margin/sending-agent-margin.component';
import { ManageAgentUsersComponent } from './manage-agent-users/manage-agent-users.component';
import { ManageAgencyUsersComponent } from './manage-agency-users/manage-agency-users.component';
import { ManageUserSubgroupsComponent } from './manage-user-subgroups/manage-user-subgroups.component';
import { ManageUserGroupRightsComponent } from './manage-user-group-rights/manage-user-group-rights.component';
import { ViewComplainceHoldListComponent } from './view-complaince-hold-list/view-complaince-hold-list.component';
import { BeneficiaryComplianceHoldComponent } from './beneficiary-compliance-hold/beneficiary-compliance-hold.component';
import { ComplianceReportComponent } from './compliance-report/compliance-report.component';
import { ComplianceUploadDataComponent } from './compliance-upload-data/compliance-upload-data.component';
import { ComplianceUploadReportComponent } from './compliance-upload-report/compliance-upload-report.component';
import { RejectBeneficiaryComplianceReleaseComponent } from './reject-beneficiary-compliance-release/reject-beneficiary-compliance-release.component';
import { ReleaseBeneficiaryComplianceRejectComponent } from './release-beneficiary-compliance-reject/release-beneficiary-compliance-reject.component';
import { ComplianceRejectedTransactionReportComponent } from './compliance-rejected-transaction-report/compliance-rejected-transaction-report.component';
import { ViewComplianceTransactionReportComponent } from './view-compliance-transaction-report/view-compliance-transaction-report.component';
import { CountryMandatoryFieldComponent } from './country-mandatory-field/country-mandatory-field.component';
import { SendingPercentageWiseComponent } from './sending-percentage-wise/sending-percentage-wise.component';
import { AgentReportsComponent } from './agent-reports/agent-reports.component';
import { ForexTreasuryComponent } from './forex-treasury/forex-treasury.component';
import { AgentBalancesComponent } from './agent-balances/agent-balances.component';
import { AllPaidTransactionsComponent } from './all-paid-transactions/all-paid-transactions.component';
import { SendReceiveTransactionListComponent } from './send-receive-transaction-list/send-receive-transaction-list.component';
import { CommissionDetailsComponent } from './commission-details/commission-details.component';
import { TransactionsStatusReportComponent } from './transactions-status-report/transactions-status-report.component';
import { SentTxnsUserWiseComponent } from './sent-txns-user-wise/sent-txns-user-wise.component';
import { TurnOverReportComponent } from './turn-over-report/turn-over-report.component';
import { AllReceiveReportComponent } from './all-receive-report/all-receive-report.component';
import { AllSentCorridorWiseComponent } from './all-sent-corridor-wise/all-sent-corridor-wise.component';
import { AllSentTransactionMisComponent } from './all-sent-transaction-mis/all-sent-transaction-mis.component';
import { StatementOfAccountComponent } from './statement-of-account/statement-of-account.component';
import { PayoutSummaryComponent } from './payout-summary/payout-summary.component';
import { PaidUnpaidTransactionsComponent } from './paid-unpaid-transactions/paid-unpaid-transactions.component';
import { ErrorLogReportComponent } from './error-log-report/error-log-report.component';
import { RebateReportComponent } from './rebate-report/rebate-report.component';
import { RegisteredCustomersDetailsComponent } from './registered-customers-details/registered-customers-details.component';
import { CountryWiseCurrencyRateComponent } from './country-wise-currency-rate/country-wise-currency-rate.component';
import { RatesSummarizedWayComponent } from './rates-summarized-way/rates-summarized-way.component';
import { BeneficiaryRegisterDetailsComponent } from './beneficiary-register-details/beneficiary-register-details.component';
import { RepushTransactionsDetailsComponent } from './repush-transactions-details/repush-transactions-details.component';
import { InstantCashTransactionsComponent } from './instant-cash-transactions/instant-cash-transactions.component';
import { TreasuryReportComponent } from './treasury-report/treasury-report.component';
import { DailyRemittanceDashboardReportComponent } from './daily-remittance-dashboard-report/daily-remittance-dashboard-report.component';
import { MonthlyFeesReconciliationReportComponent } from './monthly-fees-reconciliation-report/monthly-fees-reconciliation-report.component';
import { MgTransactionAccountDetailsComponent } from './mg-transaction-account-details/mg-transaction-account-details.component';
import { MisAuditComponent } from './mis-audit/mis-audit.component';
import { SendRemittanceComponent } from './send-remittance/send-remittance.component';
import { BlockTransactionComponent } from './block-transaction/block-transaction.component';
import { EditBeneficiaryRegistrationComponent } from './edit-beneficiary-registration/edit-beneficiary-registration.component';
import { BeneficiaryRegistrationCheckerComponent } from './beneficiary-registration-checker/beneficiary-registration-checker.component';
import { RejectedBeneficiaryComponent } from './rejected-beneficiary/rejected-beneficiary.component';
import { ChannelHoldTransactionComponent } from './channel-hold-transaction/channel-hold-transaction.component';
import { CancellationCheckerComponent } from './cancellation-checker/cancellation-checker.component';
import { CustomerRegistrationCheckerComponent } from './customer-registration-checker/customer-registration-checker.component';
import { RejectedCustomerComponent } from './rejected-customer/rejected-customer.component';
import { TransactionAmendmentComponent } from './transaction-amendment/transaction-amendment.component';
import { ChannelCancelTransactionComponent } from './channel-cancel-transaction/channel-cancel-transaction.component';
import { ApproveTransactionComponent } from './approve-transaction/approve-transaction.component';
import { ReceivingPercentageWiseComponent } from './receiving-percentage-wise/receiving-percentage-wise.component';
import { SendingSubAgentCommissionComponent } from './sending-sub-agent-commission/sending-sub-agent-commission.component';
import { ViewSendingSubAgentMarginComponent } from './view-sending-sub-agent-margin/view-sending-sub-agent-margin.component';
import { ManageCifWiseComissionComponent } from './manage-cif-wise-comission/manage-cif-wise-commission.component';
import { VatComponent } from './vat/vat.component';
import { RelationshipManagementComponent } from './relationship-management/relationship-management.component';
import { ManageRemitterOccupationComponent } from './manage-remitter-occupation/manage-remitter-occupation.component';
import { ManageSourceOfIncomeComponent } from './manage-source-of-income/manage-source-of-income.component';
import { TagMappingComponent } from './tag-mapping/tag-mapping.component';
import { MapTrMasterComponent } from './map-tr-master/map-tr-master.component';
import { ComplainceHoldTransactionProcessComponent } from './complaince-hold-transaction-process/complaince-hold-transaction-process.component';
import { ComplainceViewListApproveComponent } from './complaince-view-list-approve/complaince-view-list-approve.component';
import { BeneficiaryComplianceReleaseReportRejectComponent } from './beneficiary-compliance-release-report-reject/beneficiary-compliance-release-report-reject.component';
import { BeneficiaryComplianceReleaseReportComponent } from './beneficiary-compliance-release-report/beneficiary-compliance-release-report.component';
import { BeneficiaryComplianceHoldViewComponent } from './beneficiary-compliance-hold-view/beneficiary-compliance-hold-view.component';
import { CommissionIncomeComponent } from './commission-income/commission-income.component';
import { ViewTransactionStatusForAgentComponent } from './view-transaction-status-for-agent/view-transaction-status-for-agent.component';
import { ProgressbarModule } from 'ngx-bootstrap/progressbar';
// import { TransactionProcessLogComponent } from './transaction-process-log/transaction-process-log.component';
import { EditTransactionDetailsComponent } from './edit-transaction-details/edit-transaction-details.component';
import { MisReportComponent } from './mis-report/mis-report.component';
import { AgencyReportHeaderComponent } from './agency-report-header/agency-report-header.component';
import { SalesMarketingReportComponent } from './sales-marketing-report/sales-marketing-report.component';
import { RemittancePaidUnpaidComponent } from './remittance-paid-unpaid/remittance-paid-unpaid.component';
import { RemittanceReportHeaderComponent } from './remittance-report-header/remittance-report-header.component';
import { SessionExpiredComponent } from './session-expired/session-expired.component';
import { UploadTransactionComponent } from './upload-transaction/upload-transaction.component';
import { DownloadTransactionComponent } from './download-transaction/download-transaction.component';
import { ComplianceDetailsReportComponent } from './compliance-details-report/compliance-details-report.component';
import { PermissionDirective } from './utils/permission.directive';
import { DataMappingComponent } from './data-mapping/data-mapping.component';
import { EditStopPaymentComponent } from './edit-stop-payment/edit-stop-payment.component';
import { ViewTransactionReceiptComponent } from './view-transaction-receipt/view-transaction-receipt.component';
import { RaCtaHoldTransactionComponent } from './ra-cta-hold-transaction/ra-cta-hold-transaction.component';
import { LandingPageComponent } from './landing-page/landing-page.component';
import { NgxSpinnerModule } from 'ngx-spinner';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { ManageComplianceRejectionComponent } from './manage-compliance-rejection/manage-compliance-rejection.component'; // <-- import here
import { ToastrModule } from 'ngx-toastr';

@NgModule({
  declarations: [
    AppComponent,
    SendReceiveTransactionListComponent,
    ApproveTransactionComponent,
    LoginComponent,
    DashboardLayoutComponent,
    CountryManagementComponent,
    GlobalComponent,
    ManageCurrencyComponent,
    ManageExchangeRateComponent,
    ManageAgentCommissionComponent,
    UserManagementComponent,
    AgencyRatesComponent,
    AgentComponent,
    // TransactionProcessLogComponent,
    AgentBranchComponent,
    AgentWiseCommissionComponent,
    ManageCountryPermissionComponent,
    ManagePurposeOfTransferComponent,
    ManageModeOfPaymentComponent,
    ManageCityComponent,
    ManageLocationComponent,
    BankRatesComponent,
    MarginsSpecificSendingCountryComponent,
    AgentWiseRatesComponent,
    MarginsSpecificSendingReceivingCountryComponent,
    DailyRatesComponent,
    CountryWiseCommissionComponent,
    CifWiseMarginsComponent,
    RatesMinMaxComponent,
    EditTransactionComponent,
    EditTransactionDetailComponent,
    ViewTransactionStatusComponent,
    StopPaymentComponent,
    ManageAgentBranchesComponent,
    AllSentTransactionsComponent,
    CancellationRequestComponent,
    ViewCancelTransactionComponent,
    ViewReceiveTransactionComponent,
    ViewComplianceListComponent,
    SuspiciousTransactionReportComponent,
    IndianInboundTransactionReportComponent,
    HighValueTransactionReportComponent,
    ComplianceReleasedTransactionReportComponent,
    ComplianceHoldTransactionReportComponent,
    TransactionAccountingDetailsComponent,
    SearchTransactionsComponent,
    CancelPaidTransactionComponent,
    SearchTransactionModeWiseComponent,
    CtaHoldSummaryComponent,
    ReceiveTransactionStatusSummaryComponent,
    SentTransactionSummaryComponent,
    ViewDuplicateTransactionsComponent,
    CustomerRegistrationComponent,
    EditCustomerRegistrationComponent,
    BeneficiaryActivationComponent,
    DownloadTransactionsFileComponent,
    UploadTransactionsFileComponent,
    VostroAccountBalanceComponent,
    GlobalTransactionLimitComponent,
    CtaHoldMarginComponent,
    ManagePremiumMarginsComponent,
    EditModeOfPaymentComponent,
    SendingAgentWiseComponent,
    SendingAgentMarginComponent,
    ManageAgentUsersComponent,
    ManageAgencyUsersComponent,
    ManageUserSubgroupsComponent,
    ManageUserGroupRightsComponent,
    ViewComplainceHoldListComponent,
    BeneficiaryComplianceHoldComponent,
    ComplianceReportComponent,
    ComplianceUploadDataComponent,
    ComplianceUploadReportComponent,
    RejectBeneficiaryComplianceReleaseComponent,
    ReleaseBeneficiaryComplianceRejectComponent,
    ComplianceRejectedTransactionReportComponent,
    ViewComplianceTransactionReportComponent,
    CountryMandatoryFieldComponent,
    SendingPercentageWiseComponent,
    AgentReportsComponent,
    ForexTreasuryComponent,
    AgentBalancesComponent,
    AllPaidTransactionsComponent,
    SendReceiveTransactionListComponent,
    CommissionDetailsComponent,
    TransactionsStatusReportComponent,
    SentTxnsUserWiseComponent,
    TurnOverReportComponent,
    AllReceiveReportComponent,
    AllSentCorridorWiseComponent,
    AllSentTransactionMisComponent,
    StatementOfAccountComponent,
    PayoutSummaryComponent,
    PaidUnpaidTransactionsComponent,
    ErrorLogReportComponent,
    RebateReportComponent,
    RegisteredCustomersDetailsComponent,
    CountryWiseCurrencyRateComponent,
    RatesSummarizedWayComponent,
    BeneficiaryRegisterDetailsComponent,
    RepushTransactionsDetailsComponent,
    InstantCashTransactionsComponent,
    TreasuryReportComponent,
    DailyRemittanceDashboardReportComponent,
    MonthlyFeesReconciliationReportComponent,
    MgTransactionAccountDetailsComponent,
    MisAuditComponent,
    SendRemittanceComponent,
    BlockTransactionComponent,
    EditBeneficiaryRegistrationComponent,
    BeneficiaryRegistrationCheckerComponent,
    RejectedBeneficiaryComponent,
    ChannelHoldTransactionComponent,
    CancellationCheckerComponent,
    CustomerRegistrationCheckerComponent,
    RejectedCustomerComponent,
    TransactionAmendmentComponent,
    ChannelCancelTransactionComponent,
    ComplainceHoldTransactionProcessComponent,
    ComplainceViewListApproveComponent,
    BeneficiaryComplianceReleaseReportRejectComponent,
    BeneficiaryComplianceReleaseReportComponent,
    BeneficiaryComplianceHoldViewComponent,

    ReceivingPercentageWiseComponent,
    SendingSubAgentCommissionComponent,
    ViewSendingSubAgentMarginComponent,
    ManageCifWiseComissionComponent,
    VatComponent,
    RelationshipManagementComponent,
    ManageRemitterOccupationComponent,
    ManageSourceOfIncomeComponent,
    TagMappingComponent,
    MapTrMasterComponent,
    CommissionIncomeComponent,
    ViewTransactionStatusForAgentComponent,
    EditTransactionDetailsComponent,
    MisReportComponent,
    AgencyReportHeaderComponent,
    SalesMarketingReportComponent,
    RemittancePaidUnpaidComponent,
    RemittanceReportHeaderComponent,
    SessionExpiredComponent,
    UploadTransactionComponent,
    DownloadTransactionComponent,
    ComplianceDetailsReportComponent,
    PermissionDirective,
    DataMappingComponent,
    EditStopPaymentComponent,
    ViewTransactionReceiptComponent,
    RaCtaHoldTransactionComponent,
    LandingPageComponent,
    ManageComplianceRejectionComponent,
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    FormsModule,
    ReactiveFormsModule,
    BrowserAnimationsModule,
    HttpClientModule,
    ModalModule.forRoot(),
    NgSelectModule,
    ToastrModule.forRoot(),

    ProgressbarModule.forRoot(),
    NgxSpinnerModule.forRoot(),
  ],
  providers: [
    { provide: HTTP_INTERCEPTORS, useClass: TokenInterceptor, multi: true },
  ],
  bootstrap: [AppComponent],
})
export class AppModule {}
