import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { ViewComplainceHoldListService } from '../services/view-complaince-hold-list.service';
import { getCacheData } from '../utils/helper';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-complaince-hold-transaction-process',
  templateUrl: './complaince-hold-transaction-process.component.html',
  styleUrls: ['./complaince-hold-transaction-process.component.css'],
})
export class ComplainceHoldTransactionProcessComponent implements OnInit {
  transactionData: any;
  showCust: boolean = false;
  showDetails: boolean = false; // Property to control the visibility
  transactionNumber: string;
  transactionRemarkHold: string;
  remark: string;
  showDetailsTable: boolean = false;
  details: any[] = [];
  detailType: string;
  isLoading: boolean = false;
  rejectionReasons: any[] = []; // Initialize as an empty array to store rejection reasons
  CustomerRemarkHold: any;
  BeneficiaryRemarkHold: any;
  CustomerRejectionReason: any;
  BeneficiaryRejectionReason: any;
  // In your component class
  isButtonDisabled = true; // Set it to true initially or when you want to disable the button

  constructor(
    private route: ActivatedRoute,
    private viewComplianceHoldListService: ViewComplainceHoldListService,
    private router: Router,
    private toastrSvc: ToastrService
  ) {}

  showPrintButton = false;
  getPrintDetails() {
    this.isLoading = true;
    this.showPrintButton = false;

    // Simulate loading with a timeout
    setTimeout(() => {
      this.isLoading = false;
      this.showPrintButton = true;
    }, 3000); // 3 seconds delay
  }

  printPage() {
    window.print();
    // Optionally reset the buttons if needed
    this.showPrintButton = false;
    this.isLoading = false;
  }

  showCustomerDetails() {
    this.showCust = !this.showCust;

    if (this.transactionNumber) {
      this.viewComplianceHoldListService
        .viewComplianceHoldListCustomerDetail(this.transactionNumber)
        .subscribe(
          (response) => {
            console.log('Customer Details Response:', response);
            this.details = response;
            this.showDetailsTable = true;
            this.detailType = 'Customer';
          },
          (error) => {
            console.error('Error fetching customer details:', error);
          }
        );
    }
  }

  showBeneficiaryDetails() {
    if (this.transactionNumber) {
      this.viewComplianceHoldListService
        .viewComplianceHoldListBeneficiaryDetail(this.transactionNumber)
        .subscribe(
          (response) => {
            console.log('Beneficiary Details Response:', response);
            this.details = response;
            this.showDetailsTable = true;
            this.detailType = 'Beneficiary';
          },
          (error) => {
            console.error('Error fetching beneficiary details:', error);
          }
        );
    }
  }

  // getPrintDetails() {
  //   if (this.transactionNumber) {
  //     this.viewComplianceHoldListService
  //       .viewComplianceHoldListPrintDetail(this.transactionNumber)
  //       .subscribe(
  //         (response) => {
  //           console.log('Print Details Response:', response);
  //           this.details = response;
  //           this.showDetailsTable = true;
  //           this.detailType = 'Print';
  //         },
  //         (error) => {
  //           console.error('Error fetching print details:', error);
  //         }
  //       );
  //   }
  // }

  ngOnInit() {
    this.transactionNumber = this.route.snapshot.paramMap.get('id');

    this.loadDetailsList();
    this.loadComplianceList();
  }

  loadDetailsList() {
    if (this.transactionNumber) {
      this.viewComplianceHoldListService
        .viewComplianceHoldListDetails(this.transactionNumber, 'N')
        .subscribe(
          (response) => {
            this.transactionData = response;
          },
          (error) => {
            this.transactionData = [];
            console.error('Error fetching transaction details:', error);
          }
        );
    }
  }

  loadComplianceList() {
    this.viewComplianceHoldListService.rejectionReason().subscribe(
      (response: any) => {
        this.rejectionReasons = response.filter(
          (reason: any) => reason.IsActive
        );

        console.log('Rejection reasons:', this.rejectionReasons);
      },
      (error) => {
        console.error('Error fetching rejection reasons:', error);
      }
    );
  }

  showBeneficiaryDetailsTable() {
    this.showDetails = !this.showDetails; // Toggle the visibility

    if (this.transactionNumber) {
      this.viewComplianceHoldListService
        .viewComplianceHoldListBeneficiaryDetail(this.transactionNumber)
        .subscribe(
          (response) => {
            console.log('Beneficiary Details Response:', response);
            this.details = response;
            this.showDetailsTable = true;
            this.detailType = 'Beneficiary';
          },
          (error) => {
            console.error('Error fetching beneficiary details:', error);
          }
        );
    }
  }

  releaseComplianceHold() {
    if (!this.remark) {
      alert('Please enter a remark for releasing.');
      return;
    }

    if (this.transactionNumber) {
      const releasePayload = {
        TransactionNumber: this.transactionNumber,
        Remark: this.remark,
        UserID: getCacheData('G_UserID'),
        IsMGTxn:
          this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
            ?.IsMGTxn,
        IsMTOSuccess:
          this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
            ?.IsMTOSuccess,
        OrgMsgID:
          this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
            ?.OrgMsgID,
      };

      this.viewComplianceHoldListService
        .viewComplianceHoldListRelease(releasePayload)
        .subscribe(
          (response) => {
            console.log('Release response:', response);
            this.router.navigate(['/panel/view-compliance-hold-list']);
            // alert(`Transaction number ${this.transactionNumber} is approved.`);
            // alert(response);          
            this.toastrSvc.success(response);

            this.remark = '';
          },
          (error) => {
            console.error('Error releasing hold:', error);
            this.remark = '';
          }
        );
    } else {
      console.error('Transaction number is required for releasing hold.');
    }
  }

  rejectComplianceHold() {
    if (!this.remark) {
      alert('Please enter a reason for rejection.');
      return;
    }

    if (this.transactionNumber) {
      const rejectPayload = {
        TransactionNumber: this.transactionNumber,
        UserID: getCacheData('G_UserID'),
        IsMGTxn:
          this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
            ?.IsMGTxn,
        IsMTOSuccess:
          this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
            ?.IsMTOSuccess,
        RejectReason: this.remark,
        OrgMsgID:
          this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
            ?.OrgMsgID,
      };

      this.viewComplianceHoldListService
        .viewComplianceHoldListReject(rejectPayload)
        .subscribe(
          (response) => {
            console.log('Reject response:', response);
            this.router.navigate(['/panel/view-compliance-hold-list']);
            // alert(`Transaction number ${this.transactionNumber} is Rejected. `);
            // alert(response);
            this.toastrSvc.success(response);

            this.remark = '';
          },
          (error) => {
            console.error('Error rejecting hold:', error);
            this.remark = '';
          }
        );
    }
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  navigateBack() {
    // Replace '/complaince-hold-transaction-process' with the desired URL
    this.router.navigateByUrl('/panel/view-compliance-hold-list');
  }

  // In your component (TypeScript file)

  calculateTotal(): number {
    const agentLCAmount = parseFloat(
      this.transactionData[0]?.ViewComplainceHoldListViewResponse[0]
        ?.AgentLC_Amount || '0'
    );
    const baseToBaseCommissionAmount = parseFloat(
      this.transactionData[0]?.ViewComplainceHoldListViewResponse[0]
        ?.BaseToBaseCommissionAmount || '0'
    );

    return agentLCAmount + baseToBaseCommissionAmount;
  }

  onReject() {
    if (!this.remark) {
      return alert('Please enter a remark before Reject compliance.');
    }
    this.isLoading = true;
    const payload = {
      TransactionNumber: this.transactionNumber,
      UserID: getCacheData('G_UserID'),
      IsMGTxn:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.IsMGTxn,
      IsMTOSuccess:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.IsMTOSuccess,
      RejectReason: 'Other',
      Remark: this.remark,
      OrgMsgID:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.OrgMsgID,
    };

    this.viewComplianceHoldListService.transactionReject(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());
        this.isLoading = false;
        this.remark = '';
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.remark = '';
      }
    );
  }

  CustomeronReject() {
    // if (!this.CustomerRemarkHold) {
    //   return alert('Please enter a remark before Reject compliance.');
    // }
    this.isLoading = true;
    const payload = {
      TransactionNumber: this.transactionNumber,
      UserID: getCacheData('G_UserID'),
      IsMGTxn:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.IsMGTxn,
      IsMTOSuccess:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.IsMTOSuccess,
      RejectReason: this.CustomerRejectionReason,
      Remark: this.CustomerRemarkHold,
      OrgMsgID:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.OrgMsgID,
      CustomerBeneficiaryNo:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.CustNumber,
    };

    this.viewComplianceHoldListService.customerReject(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());
        this.isLoading = false;
        this.CustomerRemarkHold = '';
        this.loadDetailsList();
        this.loadComplianceList();
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.CustomerRemarkHold = '';
      }
    );
  }

  CustomerApprove() {
    // if (!this.CustomerRemarkHold) {
    //   return alert('Please enter a remark before Approve Customer.');
    // }
    const payload = {
      TransactionNumber: this.transactionNumber,
      UserID: getCacheData('G_UserID'),
      Remark: this.CustomerRemarkHold,
      CustomerBeneficiaryNo:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          ?.CustNumber,
    };

    this.isLoading = true;

    this.viewComplianceHoldListService.customerApprove(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());
        this.isLoading = false;
        this.CustomerRemarkHold = '';
        this.loadDetailsList();
        this.loadComplianceList();
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.CustomerRemarkHold = '';
      }
    );
  }

  BeneficiaryApprove() {
    // if (!this.BeneficiaryRemarkHold) {
    //   return alert('Please enter a remark before Approve Beneficiary.');
    // }
    this.isLoading = true;
    const payload = {
      CustStatus:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .ISCustInCompliance,
      CustApprove:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .ISCustApprove,
      TransactionNumber: this.transactionNumber,
      Remark: this.BeneficiaryRemarkHold,
      UserID: getCacheData('G_UserID'),
      CustomerBeneficiaryNo:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .BenNo,
      BENStatus:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .IsBenInCompliance,
      BENApprove:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .IsBenApprove,
      IsMGTxn:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .IsMGTxn,
      TxnExpired: 'N',
      TxnTime:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .TxnTime,
      MGWaitMin:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .MGWaitMin,
      OrgMsgID:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .OrgMsgID,
      IsMTOSuccess:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .IsMTOSuccess,
      RejectReason: this.BeneficiaryRejectionReason,
    };

    this.viewComplianceHoldListService.beneficiaryApprove(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());
        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
        this.loadDetailsList();
        this.loadComplianceList();
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
      }
    );
  }

  BeneficiarReject() {
    // if (!this.BeneficiaryRemarkHold) {
    //   return alert('Please enter a remark before Reject Customer.');
    // }
    this.isLoading = true;
    const payload = {
      TransactionNumber: this.transactionNumber,
      UserID: getCacheData('G_UserID'),
      IsMGTxn:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .IsMGTxn,
      IsMTOSuccess:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .IsMTOSuccess,
      RejectReason: this.BeneficiaryRejectionReason,
      Remark: this.BeneficiaryRemarkHold,
      OrgMsgID:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .OrgMsgID,
      CustomerBeneficiaryNo:
        this.transactionData[0]?.ViewComplainceHoldListGetRequiredResponse[0]
          .BenNo,
    };

    this.viewComplianceHoldListService.beneficiaryReject(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());
        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
        this.loadDetailsList();
        this.loadComplianceList();
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
      }
    );
  }
}
