import { Component, ElementRef, ViewChild } from '@angular/core';
import { ComplianceDetailService } from '../services/compliance-details.service';
import * as XLSX from 'xlsx';


@Component({
  selector: 'app-compliance-details-report',
  templateUrl: './compliance-details-report.component.html',
  styleUrls: ['./compliance-details-report.component.css']
})
export class ComplianceDetailsReportComponent {
  @ViewChild('complianceDetailReportTable') complianceDetailReportTable: ElementRef;
  isLoading: boolean = false;
  fromDate: string = new Date(new Date().toLocaleString("en-US", {timeZone: "Asia/Riyadh"})).toISOString().substring(0, 10);
  toDate: string = new Date(new Date().toLocaleString("en-US", {timeZone: "Asia/Riyadh"})).toISOString().substring(0, 10);
  
  status = [{
    statusId: 4,
    statusValue: 'Compliance Block'
  }, {
    statusId: 2,
    statusValue: 'Compliance Released'
  },
  {
    statusId: 25,
    statusValue: 'Compliance Rejected'
  },
  {
    statusId: 26,
    statusValue: 'Compliance Hold'
  }]
  selectedStatus: any = 0;

  complianceDetails: any = [];
  selectedFileFormat: any = '1';


  constructor(
    private complianceDetailSvc: ComplianceDetailService
  ) { }


  submit() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From & To Date!');
      return;
    }

    this.isLoading = true;

    this.complianceDetailSvc.getComplianceDetailsReport(this.fromDate, this.toDate, this.selectedStatus)
      .subscribe({
        next: (res: any) => {
          this.isLoading = false;
          if (res?.length === 0) {
            this.complianceDetails = [];
            alert('No data found.');
            return;
          }
          this.complianceDetails = res.map(obj => this.replaceKeysWithUnderscores(obj));
        },
        error: (err) => {
          this.isLoading = false;
          this.complianceDetails = [];
          alert(err?.error?.message || 'Something went wrong');
        }
      });
  }

  replaceKeysWithUnderscores(obj: any) {
    const newObj: any = {};
    for (const key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        const newKey = key.replace(/\s+/g, '_');
        newObj[newKey] = obj[key];
      }
    }
    return newObj;
  }
  exportToExcel() {
    const ws: XLSX.WorkSheet = XLSX.utils.json_to_sheet(this.complianceDetails);

    // Adjust column widths to ensure all text is visible
    const columnWidths = this.getColumnWidths(this.complianceDetails);
    ws['!cols'] = columnWidths;

    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');
    const fileName = `Compliance_Details_Report_${Date.now()}.xlsx`;
    XLSX.writeFile(wb, fileName);
  }

  getColumnWidths(data: any[]): XLSX.ColInfo[] {
    const maxWidth = 100; // Maximum width in characters
    const minWidth = 10; // Minimum width in characters
    const defaultWidth = 20; // Default width in characters

    const widths: XLSX.ColInfo[] = [];
    if (data.length > 0) {
      Object.keys(data[0]).forEach(key => {
        const maxCellLength = Math.max(...data.map(item => item[key] ? String(item[key]).length : 0));
        const width = Math.min(maxWidth, Math.max(minWidth, maxCellLength + 5)); // Adding 5 to ensure padding
        widths.push({ wch: width });
      });
    } else {
      // If no data, set default widths for demonstration
      widths.push({ wch: defaultWidth });
    }
    return widths;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
