import { DOCUMENT } from '@angular/common';
import { Component, Inject } from '@angular/core';
import { AuthService } from '../services/auth.service';
import { Router } from '@angular/router';
import { ManageAgencyUsersService } from '../manage-agency-users.service';
import { PermissionService } from '../services/permission.service';
import { getCacheData } from '../utils/helper';

interface MenuItem {
  FunctionID: number;
  FunctionName: string;
  ParentName: string;
  SequenceID: number;
  LevelID: number;
  NavigationUrl: string;
  children?: MenuItem[];
}

@Component({
  selector: 'app-dashboard-layout',
  templateUrl: './dashboard-layout.component.html',
  styleUrls: ['./dashboard-layout.component.css'],
})
export class DashboardLayoutComponent {
  public menuList: MenuItem[] = [];
  iconMap: { [key: string]: string } = {
    'Back Office Management': 'assets/images/sidebarnav-icon/1.svg',
    'User Management': 'assets/images/sidebarnav-icon/2.svg',
    'Transaction Management': 'assets/images/sidebarnav-icon/3.svg',
    Reports: 'assets/images/sidebarnav-icon/5.svg',
    'Compliance Management': 'assets/images/sidebarnav-icon/6.svg',
  };

  menuMap: { [key: string]: string } = {
    Global: '/panel/global-transaction-limit',
    'Manage Currency': '/panel/manage-currency',
    'Manage Country': '/panel/country-management',
    'Manage Purpose of Transfer': '/panel/purpose-of-transfer',
    'Manage Exchange Rates': '/panel/agency-rates',
    'Manage Exchange Margins': '/panel/manage-specific-send-country',
    'Manage Commissions': '/panel/country-wise-commission',
    'Manage Agent': '/panel/manage-agent',
    VAT: '/panel/vat',
    'Relationship Management': '/panel/relationship-management',
    'Manage Remitter Occupation': '/panel/manage-remitter-occupation',
    'Data Mapping': '/panel/data-mapping',
    'Manage Source Of Income': '/panel/manage-source-of-income',
    'Tag Mapping': '/panel/tag-mapping',
    'Map TR Master with MG Master': '/panel/map-tr-master',
    'Manage Agent User': '/panel/manage-agent-user',
    'Manage User Group': '/panel/manage-user-subgroups',
    'Manage Agency User': '/panel/manage-agency-user',
    'View Compliance List': '/panel/view-compliance-list',
    'View Complaince Hold List': '/panel/view-compliance-hold-list',
    'Compliance Report': '/panel/compliance-report',
    'Beneficiary Compliance Hold': '/panel/beneficiary-compliance-hold',
    'Compliance Upload Data': '/panel/compliance-upload-data',
    'Compliance Upload Report': '/panel/compliance-upload-report',
    'Compliance Reports': '/panel/suspicious-transaction-report',
    Agency: '/panel/forex-treasury',
    'All Sent Transactions': '/panel/all-sent-transaction',
    Remittance: '/panel/send-remittance',
    'Rebate Report': '/panel/rebate-report',
    'Country Wise Currency Rate': '/panel/country-wise-currency-rate',
    'Registered Customers Details': '/panel/registered-customers-details',
    'View PayOut Banks Log': '/panel/#',
    'Beneficiary Register Details': '/panel/beneficiary-register-details',
    'Rates In Summarized Way': '/panel/rates-summarized-way',
    'Repush Transactions Details': '/panel/repush-transactions-details',
    'Instant Cash Transactions Details':
      '/panel/instant-cash-transactions-details',
    'Treasury Report': '/panel/treasury-report',
    'Daily Remittance Dashboard Report':
      '/panel/daily-remittance-dashboard-report',
    'Monthly Fees Reconciliation Report':
      '/panel/monthly-fees-reconciliation-report',
    'MG Treasury Report': '/panel/#',
    'MG Transaction Account Details': '/panel/mg-transaction-account-details',
    'RA CTA Hold Transaction': '/panel/ra-cta-hold-transaction',
    'Edit Transaction': '/panel/edit-transaction',
    'Edit Transaction Details': '/panel/edit-transaction-details',
    'View Transaction Status': '/panel/view-transaction-status-for-agent',
    'Stop Payment': '/panel/stop-payment',
    'Cancellation Request': '/panel/cancel-request',
    'Approve Transaction': '/panel/approve-transaction',
    'View Pending for Approval': '/panel/view-pending-approval',
    'Transaction Process Log': '/panel/transaction-process-log',
    'Block Transaction': '/panel/block-transaction',
    'Block Unblock Transaction': '/panel/block-unblock-transaction',
    'SA CTA Hold Transaction': '/panel/send-agent-cta-transaction',
    'Rejected Beneficiary': '/panel/rejected-beneficiary',
    'Channel Hold Transaction(s)': '/panel/channel-hold-transaction',
    'Rejected Customer': '/panel/rejected-customer',
    'Beneficiary Registration': '/panel/beneficiary-register',
    'Edit Beneficiary Registration': '/panel/edit-beneficiary-registration',
    'Beneficiary Registration(Checker)':
      '/panel/beneficiary-registration-checker',
    'Cancellation(Checker)': '/panel/cancellation-checker',
    'Customer Registration(Checker)': '/panel/customer-registration-checker',
    'View Cancel Transaction(s)': '/panel/view-cancel-transaction',
    'View Receive Transaction': '/panel/view-receive-transaction',
    'Search Transactions': '/panel/search-transactions',
    'Cancel Paid Transaction': '/panel/cancel-paid-transaction',
    'Search Transactions - Mode Wise': '/panel/search-transactions-mode-wise',
    'CTA Hold Summary': '/panel/cta-hold-summary',
    'Channel Cancel Transaction(s)': '/panel/channel-cancel-transaction',
    'Receive Transaction Status Summary':
      '/panel/receive-transaction-status-summary',
    'Remove Transaction': '/panel/remove-transaction',
    'Sent Transaction Summary': '/panel/sent-transaction-summary',
    'View Duplicate Transactions': '/panel/view-duplicate-transaction',
    'Customer Registration': '/panel/customer-registration',
    'Edit Customer Registration': '/panel/edit-customer-registration',
    'Beneficiary Activation': '/panel/beneficiary-activation',
    'Download Transactions File': '/panel/download-transactions-file',
    'Upload Transactions File': '/panel/upload-transactions-file',
    'Vostro Account Balance': '/panel/vostro-account-balance',
    'Manage Compliance Rejection Reason': '/panel/manage-compliance-rejection',
    'Transaction Account Details': '/panel/transaction-account-details',
    'Transaction Amendment (MG)': '/panel/transaction-amendment',
    'Turn Over Report': '/panel/turn-over-report',
    'All Paid Transactions': '/panel/all-paid-transaction',
  };

  constructor(
    @Inject(DOCUMENT) private document: Document,
    private authSvc: AuthService,
    private agencyUserSvc: ManageAgencyUsersService,
    private permissionService: PermissionService,
    private router: Router
  ) {
    this.document.body.classList.add('admin-body');
  }

  ngOnInit(): void {
    this.getUserPermissions();
    this.getMenuList();
  }

  getUserPermissions() {
    this.agencyUserSvc
      .set(
        getCacheData('G_UserID'),
        getCacheData('G_UserGroup'),
        getCacheData('SubUserGroup_Id')
      )
      .subscribe({
        next: (res: any) => {
          if (res?.length > 0) {
            this.permissionService.updatePermissions(
              res?.[0]?.manageAgencyUserPopulateGroupResponse
            );
          }
        },
        error: (err) => {},
        complete: () => {},
      });
  }

  getMenuList() {
    this.authSvc.getMenuList().subscribe({
      next: (res: any) => {
        if (res?.length > 0) {
          this.menuList = this.buildHierarchy(res?.[0].MenuList);
        }
      },
      error: (err) => {},
      complete: () => {},
    });
  }

  buildHierarchy(items: MenuItem[]): MenuItem[] {
    const itemMap = new Map<number, MenuItem>();
    const roots: MenuItem[] = [];

    items.forEach((item) => {
      item.children = [];
      itemMap.set(item.FunctionID, item);
    });

    items.forEach((item) => {
      if (item.ParentName === '0') {
        roots.push(item);
      } else {
        const parent = items.find(
          (parentItem) => parentItem.FunctionName === item.ParentName
        );
        if (parent) {
          parent.children?.push(item);
        }
      }
    });

    return roots;
  }

  ngOnDestroy() {
    this.document.body.classList.remove('admin-body');
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  userLogOut() {
    this.authSvc.userLogOut().subscribe({
      next: (res: any) => {
        if (res) {
          sessionStorage.clear();
          this.router.navigate(['/login']);
        }
      },
      error: (err) => {
        alert(err?.error?.message);
      },
      complete: () => {
        sessionStorage.clear();
        this.router.navigate(['/login']);
      },
    });
  }
  isActive(paths: string[]): boolean {
    return paths.some((path) => this.router.url.startsWith(path));
  }

  getIconUrl(functionName: string): string {
    return this.iconMap[functionName] || '';
  }

  getMenuPath(menuItem: MenuItem): string {
    return this.menuMap[menuItem.FunctionName] || '#';
  }
}
