import {
  Component,
  ElementRef,
  Inject,
  OnInit,
  TemplateRef,
  ViewChild,
} from '@angular/core';
import { DOCUMENT } from '@angular/common';
import {
  FormBuilder,
  FormControl,
  FormGroup,
  Validators,
} from '@angular/forms';
import { AuthService } from '../services/auth.service';
import { Router } from '@angular/router';
import { setCacheData } from '../utils/helper';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.css'],
})
export class LoginComponent implements OnInit {
  @ViewChild('userLogin') userLoginModal;
  bsModalRef: BsModalRef;
  @ViewChild('usernameInput') usernameInput: ElementRef;

  loginForm = new FormGroup({
    username: new FormControl('', Validators.required),
    password: new FormControl('', Validators.required),
  });

  showPassword = false;
  loading = false;
  userId: any = '';

  constructor(
    @Inject(DOCUMENT) private document: Document,
    private fb: FormBuilder,
    private authService: AuthService,
    private modalService: BsModalService,
    private router: Router
  ) {
    this.document.body.classList.add('login-page');
  }

  ngOnInit(): void {}

  ngAfterViewInit() {
    // Set focus on the username input field when the view is initialized
    this.usernameInput.nativeElement.focus();
  }

  get f() {
    return this.loginForm.value;
  }

  submitForm() {
    if (this.loginForm.valid) {
      this.loading = true;
      this.authService.login(this.f.username, this.f.password).subscribe({
        next: (res: any) => {
          if (
            res?.[0]?.UserAlreadyLoginResponse?.[0]?.UserID ||
            res?.[0]?.loginResponse?.[0]?.G_UserID
          ) {
            this.userId = res?.[0]?.UserAlreadyLoginResponse?.[0]?.UserID
              ? res?.[0]?.UserAlreadyLoginResponse?.[0]?.UserID
              : res?.[0]?.loginResponse?.[0]?.G_UserID;
            this.openUserLoginModal();
          }
        },
        error: (err) => {
          this.loading = false;
          alert(err?.error?.message);
        },
        complete: () => {
          this.loading = false;
        },
      });
    }
  }

  togglePassword() {
    this.showPassword = !this.showPassword;
  }

  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template);
  }

  openUserLoginModal() {
    this.openModal(this.userLoginModal);
  }

  proceed() {
    if (this.userId) {
      this.authService
        .userAlreadyLoginYes(this.userId, this.f.username)
        .subscribe({
          next: (res: any) => {
            if (res) {
              setCacheData('admin_token', res?.AuthorizationToken);
              setCacheData('username', res?.G_UserName);
              setCacheData('G_UserGroup', res?.G_UserGroup);
              setCacheData('SubUserGroup_Id', res?.SubUserGroup_Id);
              setCacheData('G_UserID', res?.G_UserID);
              setCacheData('CurrentLogin_ID', res?.CurrentLogin_ID);
              this.modalService.hide();
              this.router.navigate(['/panel/home']);
            }
          },
          error: (err) => {
            this.modalService.hide();
            alert(err?.error?.message);
          },
          complete: () => {
            this.modalService.hide();
          },
        });
    }
  }

  cancel() {
    if (this.userId) {
      this.authService.userAlreadyLoginNo(this.userId).subscribe({
        next: (res: any) => {
          this.modalService.hide();
        },
        error: (err) => {
          this.modalService.hide();
        },
        complete: () => {
          this.modalService.hide();
        },
      });
    }
  }

  ngOnDestroy() {
    this.document.body.classList.remove('login-page');
  }
}
