import { Component } from '@angular/core';
import { ReceiveTransactionStatusSummaryService } from '../services/receive-transaction-status-summary.service';
import { AuthService } from '../services/auth.service';

@Component({
  selector: 'app-receive-transaction-status-summary',
  templateUrl: './receive-transaction-status-summary.component.html',
  styleUrls: ['./receive-transaction-status-summary.component.css'],
})
export class ReceiveTransactionStatusSummaryComponent {
  countryList: any = [];
  isLoading: boolean = false;

  selectedCountry: any;
  agentList: any = [];
  selectedAgent: any;
  fromDate: any = '';
  toDate: any = '';
  statusList: any = [
    {
      id: 0,
      type: '--All--',
    },
    {
      id: 2,
      type: 'Unpaid',
    },
    {
      id: 29,
      type: 'InProcess',
    },
    {
      id: 3,
      type: 'Paid',
    },
  ];
  selectedStatus: any = 0;
  allReceiveTransactions: any = [];
  today: string;
  minFromDate: string;
  isInvalidRange: boolean = false;

  constructor(
    private receiveTransactionSvc: ReceiveTransactionStatusSummaryService,
    private authSvc: AuthService
  ) {
    this.today = new Date().toISOString().split('T')[0];
  }

  ngOnInit(): void {
    this.getCountryList();
    this.getAgentList(0);
    this.fromDate = this.authSvc.getTodayDate();
    this.toDate = this.authSvc.getTodayDate();
  }

  // onSelectDates() {
  //   try {
  //     const startDateObj = new Date(this.fromDate);
  //     const endDateObj = new Date(this.toDate);

  //     const sixMonthsBeforeStartDate = new Date(startDateObj);
  //     sixMonthsBeforeStartDate.setMonth(
  //       sixMonthsBeforeStartDate.getMonth() - 6
  //     );

  //     if (endDateObj.getTime() !== sixMonthsBeforeStartDate.getTime()) {
  //       this.isInvalidRange = true;
  //     } else {
  //       this.isInvalidRange = false; // Reset to false if validation passes
  //     }
  //   } catch (error) {
  //     this.isInvalidRange = false; // Reset to false on any error
  //   }
  // }

  onSelectDates() {
    try {
      const startDateObj = new Date(this.fromDate);
      const endDateObj = new Date(this.toDate);

      // Calculate the date 6 months before the start date
      const sixMonthsBeforeStartDate = new Date(startDateObj);
      sixMonthsBeforeStartDate.setMonth(
        sixMonthsBeforeStartDate.getMonth() - 6
      );

      // Calculate the date 6 months after the start date
      const sixMonthsAfterStartDate = new Date(startDateObj);
      sixMonthsAfterStartDate.setMonth(sixMonthsAfterStartDate.getMonth() + 6);

      // Check if end date is within the 6-month range from start date
      if (
        endDateObj < sixMonthsBeforeStartDate ||
        endDateObj > sixMonthsAfterStartDate
      ) {
        this.isInvalidRange = true; // Invalid range
      } else {
        this.isInvalidRange = false; // Valid range
      }
    } catch (error) {
      this.isInvalidRange = true; // Handle errors by setting isInvalidRange to true
    }
  }

  getCountryList() {
    this.receiveTransactionSvc.getCountryList().subscribe({
      next: (res: any) => {
        this.countryList = res;
        this.selectedCountry = res?.[0]?.CountryId;
      },
      error: (err) => {
        this.countryList = [];
      },
      complete: () => {},
    });
  }

  onCountryChange(countryId: any) {
    if (countryId != 0) {
      this.getAgentList(countryId);
    }
  }

  getAgentList(countryId: any = 0) {
    this.receiveTransactionSvc.getAgentList(countryId).subscribe({
      next: (res: any) => {
        this.agentList = res;
        this.selectedAgent = res?.[0]?.Agent_ID;
      },
      error: (err) => {
        this.agentList = [];
      },
      complete: () => {},
    });
  }

  displayByDate() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From & To Date!');
      return;
    }
    this.isLoading = true;
    this.receiveTransactionSvc
      .getAllRecord(
        this.fromDate,
        this.toDate,
        this.selectedCountry,
        this.selectedAgent,
        this.selectedStatus
      )
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            alert('No data found.');
            return;
          }
          this.isLoading = false;
          const sanitizedDataArray = this.removeHtmlTagsFromArrayOfObjects(res);
          this.allReceiveTransactions = sanitizedDataArray;
          if (this.allReceiveTransactions?.length) {
            this.allReceiveTransactions.forEach((item) => {
              if (typeof item === 'object' && item !== null) {
                item.isBold = false;
                item.isBold =
                  item.agentname.toLowerCase().includes('country total') ||
                  item.agentname.toLowerCase().includes('grand total');
              }
            });
          }
        },
        error: (err) => {
          this.isLoading = false;
          alert(err?.error?.message);
          this.allReceiveTransactions = [];
        },
        complete: () => {},
      });
  }

  sanitizeHTML(htmlString: string): string {
    const doc = new DOMParser().parseFromString(htmlString, 'text/html');
    return doc.body.textContent || '';
  }

  removeHtmlTagsFromArrayOfObjects(arr: any[]): any[] {
    return arr.map((obj) => {
      const newObj: any = {};
      for (const key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          const value = obj[key];
          if (typeof value === 'string') {
            newObj[key] = value.replace(/<[^>]*>/g, ''); // Remove HTML tags using regex
          } else {
            newObj[key] = value;
          }
        }
      }
      return newObj;
    });
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
