import { Component, TemplateRef, ViewChild } from '@angular/core';
import { SendingAgentMarginService } from '../services/sending-agent-margin.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { count } from 'rxjs';
import { getCacheData } from '../utils/helper';

@Component({
  selector: 'app-sending-agent-margin',
  templateUrl: './sending-agent-margin.component.html',
  styleUrls: ['./sending-agent-margin.component.css'],
})
export class SendingAgentMarginComponent {
  @ViewChild('sendingAgent') sendingAgentModal;
  bsModalRef: BsModalRef;

  countryList: any = [];
  selectedCountry: any;
  agentList: any = [];
  selectedAgent: any;
  sendCountryAddList: any = [];
  agentAddList: any = [];
  settlementCurrencyList: any = [];
  Agent_ID: any;
  receiveCountry: any;
  receiveCurrency: any;
  countryId: any;
  sendingAgentMargins: any[] = []; // Initializes as an empty array

  type: any = 'add';
  agentCurrency: any;

  sendingAgentMarginForm = new FormGroup({
    PayInCountryId: new FormControl('None', Validators.required),
    Agent_ID: new FormControl('None', Validators.required),
    Agent_CurrencyID: new FormControl('None', Validators.required),
    Target_CountryID: new FormControl('None', Validators.required),
    Target_CurrencyID: new FormControl('None', Validators.required),
    // Margin_Rate: new FormControl('', Validators.required),
    Margin_Rate: new FormControl('', [
      Validators.required,
      Validators.min(0.0), // Minimum value
      Validators.max(100.0), // Maximum value
    ]),

    UserID: new FormControl('', Validators.required),
    Agent_Currency: new FormControl('None', Validators.required),
    Receive_Country: new FormControl('None', Validators.required),
    Receive_Currency: new FormControl('None', Validators.required),
  });

  constructor(
    private sendingAgentService: SendingAgentMarginService,
    private modalService: BsModalService
  ) {}

  ngOnInit(): void {
    this.getSendCountryList();
    this.getSendCountryAddList();
  }

  getSendCountryList() {
    this.sendingAgentService.getSendCountryList().subscribe({
      next: (res: any) => {
        this.countryList = res;
        this.selectedCountry = res?.[0]?.CountryID;
        this.getAgentList(this.selectedCountry);
      },
      error: (err) => {
        this.countryList = [];
      },
      complete: () => {},
    });
  }

  onCountryChange(countryId: any) {
    if (countryId) {
      this.countryId = countryId;
      this.getAgentList(countryId);
    }
  }

  getAgentList(countryId: any = 0) {
    this.sendingAgentService.getAgentList(countryId).subscribe({
      next: (res: any) => {
        this.agentList = res;
        this.selectedAgent = res?.[0]?.Agent_ID;
      },
      error: (err) => {
        this.agentList = [];
      },
    });
  }

  filter() {
    if (!this.selectedCountry) {
      alert('Please Select Sending Country.');
      return;
    }

    if (this.selectedAgent == '-1' || !this.selectedAgent) {
      alert('Please Select Agent.');
      return;
    }

    this.sendingAgentService
      .getFillGrid(this.selectedCountry, this.selectedAgent)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            alert('No data found.');
            return;
          }
          console.log(res);
          this.sendingAgentMargins = res;
        },
        error: (err) => {
          this.sendingAgentMargins = [];
        },
      });
  }

  getSendCountryAddList() {
    this.sendingAgentService.getSendCountryAddList().subscribe({
      next: (res: any) => {
        this.sendCountryAddList = res;
      },
      error: (err) => {
        this.sendCountryAddList = [];
      },
    });
  }

  onCountryAddChange(countryId: any) {
    if (countryId) {
      this.countryId = countryId;
      this.getSendAgentAddList(countryId);
      this.getReceiveCountry(this.countryId);
      this.getReceiveCurrency(this.countryId);
    }
  }
  getReceiveCountry(countryId) {
    this.sendingAgentService.getReceiveCountry(countryId).subscribe({
      next: (res: any) => {
        this.receiveCountry = res;
        this.sendingAgentMarginForm.patchValue({
          Receive_Country: res?.[0]?.CountryID,
        });
        console.log('res?.[0]?.CountryID: ', res?.[0]?.CountryID);
      },
      error: (err) => {
        throw err;
      },
    });
  }

  getSendAgentAddList(sendCountryId: any = 0) {
    this.sendingAgentService.getSendAgentAddList(sendCountryId).subscribe({
      next: (res: any) => {
        this.agentAddList = res;
        this.sendingAgentMarginForm.patchValue({
          Agent_ID: res?.[0]?.Agent_ID,
        });
      },
      error: (err) => {
        this.agentAddList = [];
      },
      complete: () => {
        this.getAgentCurrency(this.countryId, this.Agent_ID);
      },
    });
  }

  openModal(template: TemplateRef<any>) {
    const modalOptions = {
      class: 'modal-lg custom-modal-height', // You can adjust the size here ('sm' for small, 'lg' for large)
      initialState: {},
      ignoreBackdropClick: true,
      keyboard: false,
      animated: true,
      backdrop: true,
    };

    this.bsModalRef = this.modalService.show(template, modalOptions);
  }

  openSendingAgentMarginModal(type: any) {
    if (type == 'add') {
      this.sendingAgentMarginForm.reset({
        PayInCountryId: 'None',
      });
    }
    this.type = type;
    this.openModal(this.sendingAgentModal);
  }

  get f() {
    return this.sendingAgentMarginForm.value;
  }

  onChangeStatus(event: any) {
    this.Agent_ID = event;
    this.getAgentCurrency(this.countryId, this.Agent_ID);
  }

  onChangeCountry(event: any) {
    this.getReceiveCurrency(event);
    console.log('event: ', event);
  }

  getReceiveCurrency(countryId) {
    this.sendingAgentService.getReceiveCurrency(countryId).subscribe({
      next: (res: any) => {
        this.receiveCurrency = res;
        this.sendingAgentMarginForm.patchValue({
          Receive_Currency: res?.[0]?.Currency_Id,
        });
      },
      error: (err) => {
        throw err;
      },
    });
  }
  getAgentCurrency(CountryId, Agent_ID) {
    this.sendingAgentService.getAgentCurrency(CountryId, Agent_ID).subscribe({
      next: (res: any) => {
        this.agentCurrency = res;
        this.sendingAgentMarginForm.patchValue({
          Agent_Currency: res?.[0]?.Currency_Id,
        });
        console.log('res: ', res);
      },
      error: (err) => {
        throw err;
      },
    });
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  updateModeofPayment() {
    const marginRateControl = this.sendingAgentMarginForm.get('Margin_Rate');

    if (marginRateControl.invalid) {
      alert('Margin must be between 0.0000 and 100.0000.');
      return;
    }

    const formData = this.sendingAgentMarginForm.value;

    const params = {
      PayInCountryId: parseInt(formData.PayInCountryId, 10),
      Agent_ID: parseInt(formData.Agent_ID, 10),
      Agent_CurrencyID: parseInt(formData.Agent_Currency, 10),
      Target_CountryID: parseInt(formData.Receive_Country, 10),
      Target_CurrencyID: parseInt(formData.Receive_Currency, 10),
      Margin_Rate: formData.Margin_Rate,
      UserID: getCacheData('G_UserID'),
      // UserID: parseInt(formData.UserID, 10),
    };

    this.sendingAgentService.addMargin(params).subscribe({
      next: (res: any) => {
        alert('Margin added successfully');
        this.bsModalRef.hide();
      },
      error: (err) => {
        console.error('Error adding margin', err);
        alert(err?.error?.message);
      },
    });
  }

  updateSendingAgentMargin() {
    const transformedData = this.transformData(this.sendingAgentMargins);
    
    this.sendingAgentService
      .updateSendingAgentMargin(transformedData)
      .subscribe({
        next: (res: any) => {
          alert('Margin updated successfully');
        },
        error: (err) => {
          console.error('Error updating margin', err);
          alert(err?.error?.message);
        },
      });
  }

  transformData(input: any[]): any[] {
    return input.map((agent) => ({
      chkIsUpdate: true,
      ID: agent?.Table[0]?.ID,
      Margin: agent?.Table[0]?.Min_AgentMargin,
      chkIsActive: agent?.Table[0]?.Active,
      UserID: getCacheData('G_UserID'),
    }));
  }
}
