import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class AgentExchangeEarningReportService {
  private baseUrl = environment.apiUrl;

  constructor(private http: HttpClient) {}

  getReportTypes(): Observable<any> {
    const token = getCacheData('admin_token');
    const username = getCacheData('username');
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${this.baseUrl}/api/master/reports/agent-report/report-type`,
      { headers: headers }
    );
  }

  getCountries(userId: number): Observable<any> {
    const token = getCacheData('admin_token');
    const username = getCacheData('username');
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${this.baseUrl}/api/master/reports/agent-report/country?G_UserID=${userId}&G_Agent_ID=1&Agent_Country_ID=0`,
      { headers: headers }
    );
  }

  getAgents(agentId: number, countryId: number): Observable<any> {
    const token = getCacheData('admin_token');
    const username = getCacheData('username');
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${this.baseUrl}/api/master/reports/agent-report/agent?AgentID=${agentId}&CountryID=${countryId}`,
      { headers: headers }
    );
  }

  getAgentBranches(agentId: number, sendBranch: number): Observable<any> {
    const token = getCacheData('admin_token');
    const username = getCacheData('username');
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${this.baseUrl}/api/master/reports/agent-report/agent-branch?AgentID=${agentId}&SendBranch=${sendBranch}`,
      { headers: headers }
    );
  }

  getCurrencies(agentId: number): Observable<any> {
    const token = getCacheData('admin_token');
    const username = getCacheData('username');
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${this.baseUrl}/api/master/reports/agent-report/currency?AgentID=${agentId}`,
      { headers: headers }
    );
  }
}
