import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class ManageAgentUsersService {
  url = environment.apiUrl;

  constructor(private http: HttpClient) {}

  getCountryList() {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/country`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getAgentList(countryId: any = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/agent?CountryID=${countryId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getAgentBranchList(countryId: any = 0, agentId: any = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/agent-branch?CountryID=${countryId}&AgentID=${agentId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getGroupList(countryId: any = 0, agentId: any = 0, agentBranchId: any = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/group?CountryID=${countryId}&AgentID=${agentId}&AgentBranchID=${agentBranchId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getUserList(
    countryId: any = 0,
    agentId: any = 0,
    agentBranchId: any = 0,
    groupId: any = 0
  ) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/user?CountryID=${countryId}&AgentID=${agentId}&AgentBranchID=${agentBranchId}&GroupID=${groupId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getFillGrid(
    agentId: any = 0,
    agentBranchId: any = 0,
    groupId: any = 0,
    userId: any = 0
  ) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/filter?AgentID=${agentId}&AgentBranchID=${agentBranchId}&GroupID=${groupId}&UserID=${userId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }
  getDetails(G_UserGroup: any, Agent_Country_ID: any, UserNameID: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/get-detail?G_UserGroup=${G_UserGroup}&Agent_Country_ID=${Agent_Country_ID}&UserNameID=${UserNameID}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }
  getDetail( UserNameID: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/get-detail?UserNameID=${UserNameID}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  addAgentType() {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/add-agent-type`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  addCountry(AgentTypeId: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/add-country?AgentTypeId=${AgentTypeId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  addAgent(CountryID: any, AgentTypeID: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/add-agent?CountryID=${CountryID}&AgentTypeID=${AgentTypeID}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  addAgentBranch(AgentTypeID: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/add-agent-branch?AgentID=${AgentTypeID}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  gridGroup(AgentID: any, UserGroup: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/grid-group?AgentID=${AgentID}&UserGroup=${UserGroup}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  subGridGroup(UserGroup: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/grid-sub-group?UserGroup=${UserGroup}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getLoginDetails(UserId: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/login-detail?UserID=${UserId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  addGroup(AgentTypeID: any, G_UserGroup: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/add-group?G_UserGroup=${G_UserGroup}&AgentTypeID=${AgentTypeID}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  searchByBranchCode(Agent_Country_ID: any, G_UserGroup: any, BranchCode: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/search-by-branch-code?G_UserGroup=${G_UserGroup}&Agent_Country_ID=${Agent_Country_ID}&BranchCode=${BranchCode}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  add(payload: any) {
    return this.http.post(
      `${environment.apiUrl}/api/user-management/manage-agent-user/add`,
      payload,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  addUserForSameLoction(BranchID: any) {
    return this.http.get(
      `${environment.apiUrl}/api/user-management/manage-agent-user/add-user-for-same-location?BranchID=${BranchID}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  update(payload: any) {
    return this.http.patch(
      `${environment.apiUrl}/api/user-management/manage-agent-user/update`,
      payload,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  Delete(payload: any) {
    return this.http.post(
      `${environment.apiUrl}/api/user-management/manage-agent-user/delete`,
      payload,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  setAgentUser(payload: any) {
    return this.http.post(
      `${environment.apiUrl}/api/user-management/manage-agent-user/set`,
      payload,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  setAgentUserTree(payload: any) {
    return this.http.post(
      `${environment.apiUrl}/api/user-management/manage-agent-user/set-tree`,
      payload,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }
}
