import {
  Directive,
  Input,
  OnDestroy,
  OnInit,
  TemplateRef,
  ViewContainerRef,
} from '@angular/core';
import { PermissionService } from '../services/permission.service';
import { Subscription } from 'rxjs';

@Directive({
  selector: '[appPermission]',
})
export class PermissionDirective implements OnInit, OnDestroy {
  @Input() set appPermission(config: {
    firstMenu: string;
    secondMenu?: string;
    thirdMenu?: string;
    accessType?:
      | 'Access_Add'
      | 'Access_Edit'
      | 'Access_Delete'
      | 'Access_View'
      | 'Access_Approve';
  }) {
    this.menuItems = config;
    this.updateView();
  }

  private menuItems: {
    firstMenu: string;
    secondMenu?: string;
    thirdMenu?: string;
    accessType?: string;
  };
  private permissionsSubscription: Subscription;

  constructor(
    private templateRef: TemplateRef<any>,
    private viewContainer: ViewContainerRef,
    private permissionService: PermissionService
  ) {}

  ngOnInit() {
    this.permissionsSubscription =
      this.permissionService.permissions$.subscribe(() => {
        this.updateView();
      });
  }

  ngOnDestroy() {
    if (this.permissionsSubscription) {
      this.permissionsSubscription.unsubscribe();
    }
  }

  private updateView() {
    const permission = this.permissionService.checkPermission(
      this.menuItems.firstMenu,
      this.menuItems.secondMenu,
      this.menuItems.thirdMenu
    );

    if (
      permission &&
      (!this.menuItems.accessType || permission[this.menuItems.accessType])
    ) {
      // Check if there is already a view attached to the ViewContainerRef
      const hasView = this.viewContainer.length > 0;

      // If there is no view attached, create a new one
      if (!hasView) {
        this.viewContainer.createEmbeddedView(this.templateRef);
      }
    } else {
      // Clear the view container if permission is not granted
      this.viewContainer.clear();
    }
  }
}
