import { Component, ElementRef, TemplateRef, ViewChild } from '@angular/core';
import { ViewComplianceListService } from '../services/view-compliance-list.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { Router } from '@angular/router';
import * as XLSX from 'xlsx';

@Component({
  selector: 'app-view-compliance-list',
  templateUrl: './view-compliance-list.component.html',
  styleUrls: ['./view-compliance-list.component.css'],
})
export class ViewComplianceListComponent {
  @ViewChild('viewCompliance') viewComplianceModal;
  bsModalRef: BsModalRef;

  @ViewChild('complianceTable') complianceTable: ElementRef;
  @ViewChild('viewTransactionLog') viewTransactionLogModal;

  allViewComplianceList: any = [];
  transactionNo: any = '';
  // selectedFileFormat: any = '1';
  isLoading: boolean = false;
  selectedFileFormat = '1';
  allRecordList: any = [
    {
      id: -1,
      value: 'All',
    },
    {
      id: 10,
      value: '10 transactions',
    },
    {
      id: 25,
      value: '25 transactions',
    },
    {
      id: 50,
      value: '50 transactions',
    },
    {
      id: 100,
      value: '100 transactions',
    },
  ];

  selectedRecordList: any = -1;
  viewComplianceList: any = [
    { OFACIds: 'DUMMY_OFAC_ID_1' },
  ];
  transactionsLogList: any = [];

  constructor(
    private viewComplianceSvc: ViewComplianceListService,
    private modalService: BsModalService,
    private router: Router
  ) {}

  ngOnInit(): void {
    this.getFillGrid();
  }
  navigateToComplianceListTransaction(transactionNo: any) {
    this.router.navigate([
      `/panel/complaince-view-list-approve/${transactionNo}`,
    ]);
  }

  getFillGrid() {
    this.isLoading = true;
    this.viewComplianceSvc.getFillGrid().subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          this.allViewComplianceList = [];
          return;
        }
        this.allViewComplianceList = res;
      },
      error: () => {
        this.allViewComplianceList = [];
        this.isLoading = false;
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  getDataByTransactionNo(transactionNumber: any = 0) {
    this.viewComplianceSvc.getDataByTransactionNo(transactionNumber).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          this.allViewComplianceList = [];
          return;
        }
        this.allViewComplianceList = res;
      },
      error: () => {
        this.allViewComplianceList = [];
      },
      complete: () => {},
    });
  }

  getViewComplianceByTransactionNo(transactionNumber: any = 0) {
    this.viewComplianceSvc
      .getViewComplianceByTransactionNo(transactionNumber)
      .subscribe({
        next: (res: any) => {
          this.viewComplianceList = res;
          this.openModal(this.viewComplianceModal);
        },
        error: () => {
          this.viewComplianceList = [];
        },
        complete: () => {},
      });
  }

  getTransactionLogByTransactionNo(transactionNumber: any = 0) {
    this.viewComplianceSvc
      .getTransactionLogByTransactionNo(transactionNumber)
      .subscribe({
        next: (res: any) => {
          this.transactionsLogList = res;
          this.openModal(this.viewTransactionLogModal);
        },
        error: () => {
          this.transactionsLogList = [];
        },
        complete: () => {},
      });
  }

  displayData() {
    if (!this.selectedRecordList) {
      alert('Please Select Records!');
      return;
    }

    this.viewComplianceSvc.getFillGrid(this.selectedRecordList).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          this.allViewComplianceList = [];
          return;
        }
        this.allViewComplianceList = res;
      },
      error: (err) => {
        this.allViewComplianceList = [];
        alert(err?.error?.message || 'Something went wrong');
      },
      complete: () => {},
    });
  }

  filterByTransactioNo() {
    if (!this.transactionNo) {
      alert('Please Enter Transaction No!');
      return;
    }
this.isLoading=true
    this.viewComplianceSvc
      .getDataByTransactionNo(this.transactionNo)
      .subscribe({
        next: (res: any) => {
          this.isLoading=false

          if (res?.length == 0) {
            alert('No data found.');
            this.allViewComplianceList = [];
            this.isLoading=false
            return;
          }
          this.allViewComplianceList = res;
        },
        error: (err) => {
          this.allViewComplianceList = [];
          alert(err?.error?.message || 'Something went wrong');
          this.isLoading=false
        },
        complete: () => {},
      });
  }

  openComplianceModal(transactionNo: any) {
    if (transactionNo) {
      this.getViewComplianceByTransactionNo(transactionNo);
    }
  }

  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template, {
      class: 'modal-xl' // This is your newly defined class
    });
  }
  openTransactionLogModal(transactionNo: any) {
    if (transactionNo) {
      this.getTransactionLogByTransactionNo(transactionNo);
    }
  }

  exportToExcel() {
    const ws: XLSX.WorkSheet = XLSX.utils.table_to_sheet(this.complianceTable.nativeElement);
    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');
    const fileName = `Compliance_Transactions_${Date.now()}.xlsx`;
    XLSX.writeFile(wb, fileName);
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  printTransactionLog() {
    const printContents = document.getElementById('printableArea')?.innerHTML;
    const originalContents = document.body.innerHTML;

    document.body.innerHTML = `<html><head><title>Print</title></head><body>${printContents}</body></html>`;
    window.print();
    document.body.innerHTML = originalContents;
    window.location.reload(); // Reload the page to restore the original content
  }
}
