import { Component, TemplateRef, ViewChild } from '@angular/core';
import { ViewSendingSubAgentMarginService } from '../services/view-sending-sub-agent-margin.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { FormControl, FormGroup, Validators } from '@angular/forms';

@Component({
  selector: 'app-view-sending-sub-agent-margin',
  templateUrl: './view-sending-sub-agent-margin.component.html',
  styleUrls: ['./view-sending-sub-agent-margin.component.css'],
})
export class ViewSendingSubAgentMarginComponent {
  @ViewChild('viewSendingSubAgent') viewSendingSubAgentModal;
  bsModalRef: BsModalRef;

  sendCountryList: any = [];
  selectedSendCountry: any = '0';
  receiveCountryList: any = [];
  selectedReceiveCountry: any = '-1';

  viewSendingSubAgentCommission: any = [];
  type: any = 'add';

  sendCurrencyList: any = [];
  receiveCountryAddList: any = [];
  receiveCurrencyList: any = [];

  minMarginError: boolean = false;

  viewSendingSubAgentForm = new FormGroup({
    ID: new FormControl(''),
    // SendAgentID: new FormControl('None', Validators.required),
    // PayInCountryId: new FormControl('None', Validators.required),
    PayInCurrencyId: new FormControl('None', Validators.required),
    PayOutCountryId: new FormControl('None', Validators.required),
    PayOutCurrencyId: new FormControl('None', Validators.required),
    MaxAgentMargin: new FormControl('', Validators.required),
    MinAgentMargin: new FormControl('', Validators.required),
    Active: new FormControl(false),
  });

  constructor(
    private viewSendingSubAgentService: ViewSendingSubAgentMarginService,
    private modalService: BsModalService
  ) {}

  ngOnInit(): void {
    this.getSendingCountryList();
    this.getReceiveCountryList();
    this.getSendCurrencyList(8);
    this.getReceiveCountryAddList(31);
  }

  getSendingCountryList() {
    this.viewSendingSubAgentService.getSendingCountryList().subscribe({
      next: (res: any) => {
        this.sendCountryList = res;
      },
      error: (err) => {
        this.sendCountryList = [];
      },
      complete: () => {},
    });
  }

  getReceiveCountryList() {
    this.viewSendingSubAgentService.getReceiveCountryList().subscribe({
      next: (res: any) => {
        this.receiveCountryList = res;
      },
      error: (err) => {
        this.receiveCountryList = [];
      },
      complete: () => {},
    });
  }

  filter() {
    if (this.selectedSendCountry == '0') {
      alert('Please Select Sending Country.');
      return;
    }

    if (this.selectedReceiveCountry == '-1') {
      alert('Please Select Receiving Country.');
      return;
    }
    if (
      this.selectedSendCountry != '0' &&
      this.selectedReceiveCountry != '-1'
    ) {
      this.viewSendingSubAgentService
        .getAllRecord(this.selectedSendCountry, this.selectedReceiveCountry)
        .subscribe({
          next: (res: any) => {
            if (res?.length == 0) {
              alert('No data found.');
              return;
            }
            this.viewSendingSubAgentCommission = res;
          },
          error: (err) => {
            this.viewSendingSubAgentCommission = [];
          },
          complete: () => {},
        });
    }
  }

  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template);
  }

  openViewSendingSubAgentModal(type: any) {
    if (type == 'add') {
      this.viewSendingSubAgentForm.reset({
        PayInCurrencyId: 'None',
        PayOutCountryId: 'None',
      });
    }
    this.type = type;
    this.openModal(this.viewSendingSubAgentModal);
  }

  getSendCurrencyList(agentId: any = 0) {
    this.viewSendingSubAgentService.getSendCurrencyList(agentId).subscribe({
      next: (res: any) => {
        this.sendCurrencyList = res;
      },
      error: (err) => {
        this.sendCurrencyList = [];
      },
      complete: () => {},
    });
  }

  getReceiveCountryAddList(countryId: any = 0) {
    this.viewSendingSubAgentService
      .getReceiveCountryAddList(countryId)
      .subscribe({
        next: (res: any) => {
          this.receiveCountryAddList = res;
        },
        error: (err) => {
          this.receiveCountryAddList = [];
        },
        complete: () => {},
      });
  }

  onReceiveCountryChange(countryId) {
    if (countryId != 'None') {
      this.getReceiveCurrencyList(countryId);
    }
  }

  getReceiveCurrencyList(countryId: any = 0) {
    this.viewSendingSubAgentService
      .getReceiveCurrencyList(countryId)
      .subscribe({
        next: (res: any) => {
          this.receiveCurrencyList = res;
          this.viewSendingSubAgentForm.patchValue({
            PayOutCurrencyId: res?.[0]?.Currency_Id,
          });
        },
        error: (err) => {
          this.receiveCurrencyList = [];
        },
        complete: () => {},
      });
  }

  allowOneDecimal(event: Event, range: string): void {
    const inputElement = event.target as HTMLInputElement;
    const inputValue = inputElement.value;

    // Remove multiple decimals and keep only the first one
    const sanitizedValue = inputValue.replace(/(\.\d*)\./, '$1');

    // Update the input value
    inputElement.value = sanitizedValue;

    this.checkMinAgentMargin(range);
  }

  checkMinAgentMargin(margin: string): void {
    const maxMargin = this.viewSendingSubAgentForm.get('MaxAgentMargin').value;
    const minMargin = this.viewSendingSubAgentForm.get('MinAgentMargin').value;

    switch (margin) {
      case 'MinAgentMargin':
        this.minMarginError = Number(maxMargin) < Number(minMargin);
        break;

      case 'MaxAgentMargin':
        this.minMarginError = Number(maxMargin) < Number(minMargin);
        break;

      default:
        break;
    }
  }

  get f() {
    return this.viewSendingSubAgentForm.value;
  }

  addSendingSubAgentMargin() {
    if (!this.viewSendingSubAgentForm.valid) {
      alert('Please Fill Required Fields!');
      return;
    }

    if (
      !this.checkSelection(
        this.f.PayInCurrencyId,
        'Please Select Send Currency.'
      )
    ) {
      return;
    }

    if (
      !this.checkSelection(
        this.f.PayOutCountryId,
        'Please Select Receive Country.'
      )
    ) {
      return;
    }

    if (
      !this.checkSelection(
        this.f.PayOutCurrencyId,
        'Please Select Receive Currency.'
      )
    ) {
      return;
    }

    let payload;
    payload = {
      ID: 0,
      SendAgentID: 0,
      PayInCountryId: 0,
      PayInCurrencyId: this.f.PayInCurrencyId,
      PayOutCountryId: this.f.PayOutCountryId,
      PayOutCurrencyId: this.f.PayOutCurrencyId,
      MaxAgentMargin: this.f.MaxAgentMargin,
      MinAgentMargin: this.f.MinAgentMargin,
      G_UserID: 'string',
      Active: true,
    };

    if (this.type === 'edit') {
      payload = {
        ...payload,
        ID: Number(this.f.ID),
      };
    }

    const serviceMethod =
      this.type === 'add'
        ? 'addSendingSubAgentMargin'
        : 'updateSendingSubAgentMargin';

    this.viewSendingSubAgentService[serviceMethod](payload).subscribe({
      next: (res: any) => {
        this.modalService.hide();
        alert('Margin added successfully.');
      },
      error: (err) => {
        this.modalService.hide();
        alert(err?.error?.message || 'Something went wrong');
      },
      complete: () => {
        this.modalService.hide();
      },
    });
  }

  checkSelection(value: string, errorMessage: string): boolean {
    if (value == 'None') {
      alert(errorMessage);
      return false;
    }
    return true;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
